@@ -18,13 +18,13 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PLASMAVAULT_KDED_ENGINE_COMMON_H
-#define PLASMAVAULT_KDED_ENGINE_COMMON_H
+#ifndef PLASMAVAULT_KDED_ENGINE_COMMON_TYPES_H
+#define PLASMAVAULT_KDED_ENGINE_COMMON_TYPES_H
 
 #include <QString>
 #include <QHash>
 
-#define PLASMAVAULT_CONFIG_FILE "plasmavaultrc"
+#define PLASMAVAULT_CONFIG_FILE QStringLiteral("plasmavaultrc")
 
 namespace PlasmaVault {
 
